spannertools.DirectedSpanner
============================

.. abjad-lineage:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner

.. autoclass:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.written_duration
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner.__repr__
   :noindex:
